'use strict';

var web3_js = require('@solana/web3.js');

// env-shim.ts
var __DEV__ = /* @__PURE__ */ (() => process["env"].NODE_ENV === "development")();
function getApproveAccountEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["slot", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([218, 253, 170, 2, 4, 47, 25, 99])
    })
  );
}
function getApproveAccountDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["slot", web3_js.getU64Decoder()]
  ]);
}
function getApproveAccountCodec() {
  return web3_js.combineCodec(getApproveAccountEncoder(), getApproveAccountDecoder());
}
function decodeApproveAccount(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getApproveAccountDecoder()
  );
}
async function fetchApproveAccount(rpc, address, config) {
  const maybeAccount = await fetchMaybeApproveAccount(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeApproveAccount(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeApproveAccount(maybeAccount);
}
async function fetchAllApproveAccount(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeApproveAccount(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeApproveAccount(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeApproveAccount(maybeAccount)
  );
}
function getApproveAccountSize() {
  return 16;
}
function getManagerEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([221, 78, 171, 233, 213, 142, 113, 56])
    })
  );
}
function getManagerDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getManagerCodec() {
  return web3_js.combineCodec(getManagerEncoder(), getManagerDecoder());
}
function decodeManager(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getManagerDecoder()
  );
}
async function fetchManager(rpc, address, config) {
  const maybeAccount = await fetchMaybeManager(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeManager(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeManager(maybeAccount);
}
async function fetchAllManager(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeManager(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeManager(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeManager(maybeAccount));
}
function getManagerSize() {
  return 8;
}
function getTokenGroupEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["updateAuthority", web3_js.getAddressEncoder()],
      ["mint", web3_js.getAddressEncoder()],
      ["size", web3_js.getU32Encoder()],
      ["maxSize", web3_js.getU32Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([184, 107, 4, 187, 196, 55, 142, 134])
    })
  );
}
function getTokenGroupDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["updateAuthority", web3_js.getAddressDecoder()],
    ["mint", web3_js.getAddressDecoder()],
    ["size", web3_js.getU32Decoder()],
    ["maxSize", web3_js.getU32Decoder()]
  ]);
}
function getTokenGroupCodec() {
  return web3_js.combineCodec(getTokenGroupEncoder(), getTokenGroupDecoder());
}
function decodeTokenGroup(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getTokenGroupDecoder()
  );
}
async function fetchTokenGroup(rpc, address, config) {
  const maybeAccount = await fetchMaybeTokenGroup(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeTokenGroup(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeTokenGroup(maybeAccount);
}
async function fetchAllTokenGroup(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeTokenGroup(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeTokenGroup(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeTokenGroup(maybeAccount));
}
function getTokenGroupSize() {
  return 80;
}
function getTokenGroupMemberEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["mint", web3_js.getAddressEncoder()],
      ["group", web3_js.getAddressEncoder()],
      ["memberNumber", web3_js.getU32Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([17, 208, 50, 173, 30, 127, 245, 94])
    })
  );
}
function getTokenGroupMemberDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["mint", web3_js.getAddressDecoder()],
    ["group", web3_js.getAddressDecoder()],
    ["memberNumber", web3_js.getU32Decoder()]
  ]);
}
function getTokenGroupMemberCodec() {
  return web3_js.combineCodec(
    getTokenGroupMemberEncoder(),
    getTokenGroupMemberDecoder()
  );
}
function decodeTokenGroupMember(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getTokenGroupMemberDecoder()
  );
}
async function fetchTokenGroupMember(rpc, address, config) {
  const maybeAccount = await fetchMaybeTokenGroupMember(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeTokenGroupMember(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeTokenGroupMember(maybeAccount);
}
async function fetchAllTokenGroupMember(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeTokenGroupMember(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeTokenGroupMember(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeTokenGroupMember(maybeAccount)
  );
}
function getTokenGroupMemberSize() {
  return 76;
}

// src/generated/errors/wenNewStandard.ts
var WEN_NEW_STANDARD_ERROR__SIZE_EXCEEDS_MAX_SIZE = 6e3;
var WEN_NEW_STANDARD_ERROR__MAX_SIZE_BELOW_CURRENT_SIZE = 6001;
var WEN_NEW_STANDARD_ERROR__CREATOR_SHARE_INVALID = 6002;
var WEN_NEW_STANDARD_ERROR__MISSING_APPROVE_ACCOUNT = 6003;
var WEN_NEW_STANDARD_ERROR__EXPIRED_APPROVE_ACCOUNT = 6004;
var WEN_NEW_STANDARD_ERROR__INVALID_FIELD = 6005;
var WEN_NEW_STANDARD_ERROR__CREATOR_ADDRESS_INVALID = 6006;
var WEN_NEW_STANDARD_ERROR__ROYALTY_BASIS_POINTS_INVALID = 6007;
var wenNewStandardErrorMessages;
if (__DEV__) {
  wenNewStandardErrorMessages = {
    [WEN_NEW_STANDARD_ERROR__CREATOR_ADDRESS_INVALID]: `The Address you provided is invalid. Please provide a valid address.`,
    [WEN_NEW_STANDARD_ERROR__CREATOR_SHARE_INVALID]: `Creators shares must add up to 100.`,
    [WEN_NEW_STANDARD_ERROR__EXPIRED_APPROVE_ACCOUNT]: `Approve account has expired.`,
    [WEN_NEW_STANDARD_ERROR__INVALID_FIELD]: `Invalid field. You cannot use a public key as a field.`,
    [WEN_NEW_STANDARD_ERROR__MAX_SIZE_BELOW_CURRENT_SIZE]: `Max size cannot be reduced below current size.`,
    [WEN_NEW_STANDARD_ERROR__MISSING_APPROVE_ACCOUNT]: `Missing approve account.`,
    [WEN_NEW_STANDARD_ERROR__ROYALTY_BASIS_POINTS_INVALID]: `Royalty basis points must be less than or equal to 10000.`,
    [WEN_NEW_STANDARD_ERROR__SIZE_EXCEEDS_MAX_SIZE]: `Collection size exceeds max size.`
  };
}
function getWenNewStandardErrorMessage(code) {
  if (__DEV__) {
    return wenNewStandardErrorMessages[code];
  }
  return "Error message not available in production bundles. Compile with `__DEV__` set to true to see more information.";
}
var WEN_NEW_STANDARD_PROGRAM_ADDRESS = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM";
var WenNewStandardAccount = /* @__PURE__ */ ((WenNewStandardAccount2) => {
  WenNewStandardAccount2[WenNewStandardAccount2["ApproveAccount"] = 0] = "ApproveAccount";
  WenNewStandardAccount2[WenNewStandardAccount2["Manager"] = 1] = "Manager";
  WenNewStandardAccount2[WenNewStandardAccount2["TokenGroup"] = 2] = "TokenGroup";
  WenNewStandardAccount2[WenNewStandardAccount2["TokenGroupMember"] = 3] = "TokenGroupMember";
  return WenNewStandardAccount2;
})(WenNewStandardAccount || {});
function identifyWenNewStandardAccount(account) {
  const data = account instanceof Uint8Array ? account : account.data;
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([218, 253, 170, 2, 4, 47, 25, 99])
    ),
    0
  )) {
    return 0 /* ApproveAccount */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([221, 78, 171, 233, 213, 142, 113, 56])
    ),
    0
  )) {
    return 1 /* Manager */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([184, 107, 4, 187, 196, 55, 142, 134])
    ),
    0
  )) {
    return 2 /* TokenGroup */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([17, 208, 50, 173, 30, 127, 245, 94])
    ),
    0
  )) {
    return 3 /* TokenGroupMember */;
  }
  throw new Error(
    "The provided account could not be identified as a wenNewStandard account."
  );
}
var WenNewStandardInstruction = /* @__PURE__ */ ((WenNewStandardInstruction2) => {
  WenNewStandardInstruction2[WenNewStandardInstruction2["AddMetadata"] = 0] = "AddMetadata";
  WenNewStandardInstruction2[WenNewStandardInstruction2["AddMintToGroup"] = 1] = "AddMintToGroup";
  WenNewStandardInstruction2[WenNewStandardInstruction2["AddRoyalties"] = 2] = "AddRoyalties";
  WenNewStandardInstruction2[WenNewStandardInstruction2["ApproveTransfer"] = 3] = "ApproveTransfer";
  WenNewStandardInstruction2[WenNewStandardInstruction2["BurnMintAccount"] = 4] = "BurnMintAccount";
  WenNewStandardInstruction2[WenNewStandardInstruction2["CreateGroupAccount"] = 5] = "CreateGroupAccount";
  WenNewStandardInstruction2[WenNewStandardInstruction2["CreateMintAccount"] = 6] = "CreateMintAccount";
  WenNewStandardInstruction2[WenNewStandardInstruction2["Execute"] = 7] = "Execute";
  WenNewStandardInstruction2[WenNewStandardInstruction2["FreezeMintAccount"] = 8] = "FreezeMintAccount";
  WenNewStandardInstruction2[WenNewStandardInstruction2["InitManagerAccount"] = 9] = "InitManagerAccount";
  WenNewStandardInstruction2[WenNewStandardInstruction2["ModifyRoyalties"] = 10] = "ModifyRoyalties";
  WenNewStandardInstruction2[WenNewStandardInstruction2["RemoveMetadata"] = 11] = "RemoveMetadata";
  WenNewStandardInstruction2[WenNewStandardInstruction2["RemoveMintFromGroup"] = 12] = "RemoveMintFromGroup";
  WenNewStandardInstruction2[WenNewStandardInstruction2["ThawMintAccount"] = 13] = "ThawMintAccount";
  WenNewStandardInstruction2[WenNewStandardInstruction2["UpdateGroupAccount"] = 14] = "UpdateGroupAccount";
  return WenNewStandardInstruction2;
})(WenNewStandardInstruction || {});
function identifyWenNewStandardInstruction(instruction) {
  const data = instruction instanceof Uint8Array ? instruction : instruction.data;
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([231, 195, 40, 240, 67, 231, 53, 136])
    ),
    0
  )) {
    return 0 /* AddMetadata */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([236, 25, 99, 48, 185, 60, 235, 112])
    ),
    0
  )) {
    return 1 /* AddMintToGroup */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([195, 251, 126, 230, 187, 134, 168, 210])
    ),
    0
  )) {
    return 2 /* AddRoyalties */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([198, 217, 247, 150, 208, 60, 169, 244])
    ),
    0
  )) {
    return 3 /* ApproveTransfer */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([60, 58, 247, 183, 185, 54, 114, 131])
    ),
    0
  )) {
    return 4 /* BurnMintAccount */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([34, 65, 118, 12, 64, 190, 211, 145])
    ),
    0
  )) {
    return 5 /* CreateGroupAccount */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([76, 184, 50, 62, 162, 141, 47, 103])
    ),
    0
  )) {
    return 6 /* CreateMintAccount */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([105, 37, 101, 197, 75, 251, 102, 26])
    ),
    0
  )) {
    return 7 /* Execute */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([171, 30, 154, 191, 27, 0, 134, 216])
    ),
    0
  )) {
    return 8 /* FreezeMintAccount */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([63, 114, 69, 118, 3, 198, 215, 72])
    ),
    0
  )) {
    return 9 /* InitManagerAccount */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([199, 95, 20, 107, 136, 161, 93, 137])
    ),
    0
  )) {
    return 10 /* ModifyRoyalties */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([81, 68, 231, 49, 91, 8, 111, 160])
    ),
    0
  )) {
    return 11 /* RemoveMetadata */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([231, 224, 145, 240, 192, 4, 204, 218])
    ),
    0
  )) {
    return 12 /* RemoveMintFromGroup */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([27, 53, 61, 16, 162, 190, 27, 72])
    ),
    0
  )) {
    return 13 /* ThawMintAccount */;
  }
  if (web3_js.containsBytes(
    data,
    web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8).encode(
      new Uint8Array([153, 106, 174, 53, 133, 171, 207, 52])
    ),
    0
  )) {
    return 14 /* UpdateGroupAccount */;
  }
  throw new Error(
    "The provided instruction could not be identified as a wenNewStandard instruction."
  );
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function getAccountMetaFactory(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      return Object.freeze({
        address: programAddress,
        role: web3_js.AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? web3_js.AccountRole.WRITABLE : web3_js.AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? web3_js.upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && web3_js.isTransactionSigner(value);
}
function getAddMetadataArgsEncoder() {
  return web3_js.getStructEncoder([
    ["field", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["value", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())]
  ]);
}
function getAddMetadataArgsDecoder() {
  return web3_js.getStructDecoder([
    ["field", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["value", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())]
  ]);
}
function getAddMetadataArgsCodec() {
  return web3_js.combineCodec(getAddMetadataArgsEncoder(), getAddMetadataArgsDecoder());
}
function getCreatorWithShareEncoder() {
  return web3_js.getStructEncoder([
    ["address", web3_js.getAddressEncoder()],
    ["share", web3_js.getU8Encoder()]
  ]);
}
function getCreatorWithShareDecoder() {
  return web3_js.getStructDecoder([
    ["address", web3_js.getAddressDecoder()],
    ["share", web3_js.getU8Decoder()]
  ]);
}
function getCreatorWithShareCodec() {
  return web3_js.combineCodec(
    getCreatorWithShareEncoder(),
    getCreatorWithShareDecoder()
  );
}
function getRemoveMetadataArgsEncoder() {
  return web3_js.getStructEncoder([
    ["field", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["value", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())]
  ]);
}
function getRemoveMetadataArgsDecoder() {
  return web3_js.getStructDecoder([
    ["field", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["value", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())]
  ]);
}
function getRemoveMetadataArgsCodec() {
  return web3_js.combineCodec(
    getRemoveMetadataArgsEncoder(),
    getRemoveMetadataArgsDecoder()
  );
}
function getUpdateRoyaltiesArgsEncoder() {
  return web3_js.getStructEncoder([
    ["royaltyBasisPoints", web3_js.getU16Encoder()],
    ["creators", web3_js.getArrayEncoder(getCreatorWithShareEncoder())]
  ]);
}
function getUpdateRoyaltiesArgsDecoder() {
  return web3_js.getStructDecoder([
    ["royaltyBasisPoints", web3_js.getU16Decoder()],
    ["creators", web3_js.getArrayDecoder(getCreatorWithShareDecoder())]
  ]);
}
function getUpdateRoyaltiesArgsCodec() {
  return web3_js.combineCodec(
    getUpdateRoyaltiesArgsEncoder(),
    getUpdateRoyaltiesArgsDecoder()
  );
}

// src/generated/instructions/addMetadata.ts
function getAddMetadataInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["args", web3_js.getArrayEncoder(getAddMetadataArgsEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([231, 195, 40, 240, 67, 231, 53, 136])
    })
  );
}
function getAddMetadataInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["args", web3_js.getArrayDecoder(getAddMetadataArgsDecoder())]
  ]);
}
function getAddMetadataInstructionDataCodec() {
  return web3_js.combineCodec(
    getAddMetadataInstructionDataEncoder(),
    getAddMetadataInstructionDataDecoder()
  );
}
function getAddMetadataInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getAddMetadataInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseAddMetadataInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      mint: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getAddMetadataInstructionDataDecoder().decode(instruction.data)
  };
}
function getAddMintToGroupInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([236, 25, 99, 48, 185, 60, 235, 112])
    })
  );
}
function getAddMintToGroupInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getAddMintToGroupInstructionDataCodec() {
  return web3_js.combineCodec(
    getAddMintToGroupInstructionDataEncoder(),
    getAddMintToGroupInstructionDataDecoder()
  );
}
function getAddMintToGroupInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    group: { value: input.group ?? null, isWritable: true },
    member: { value: input.member ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    manager: { value: input.manager ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.group),
      getAccountMeta(accounts.member),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getAddMintToGroupInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseAddMintToGroupInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      group: getNextAccount(),
      member: getNextAccount(),
      mint: getNextAccount(),
      manager: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getAddMintToGroupInstructionDataDecoder().decode(instruction.data)
  };
}
function getAddRoyaltiesInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["args", getUpdateRoyaltiesArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([195, 251, 126, 230, 187, 134, 168, 210])
    })
  );
}
function getAddRoyaltiesInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["args", getUpdateRoyaltiesArgsDecoder()]
  ]);
}
function getAddRoyaltiesInstructionDataCodec() {
  return web3_js.combineCodec(
    getAddRoyaltiesInstructionDataEncoder(),
    getAddRoyaltiesInstructionDataDecoder()
  );
}
function getAddRoyaltiesInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: true },
    extraMetasAccount: {
      value: input.extraMetasAccount ?? null,
      isWritable: true
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.extraMetasAccount),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getAddRoyaltiesInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseAddRoyaltiesInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      mint: getNextAccount(),
      extraMetasAccount: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getAddRoyaltiesInstructionDataDecoder().decode(instruction.data)
  };
}
function getApproveTransferInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["buyAmount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([198, 217, 247, 150, 208, 60, 169, 244])
    })
  );
}
function getApproveTransferInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["buyAmount", web3_js.getU64Decoder()]
  ]);
}
function getApproveTransferInstructionDataCodec() {
  return web3_js.combineCodec(
    getApproveTransferInstructionDataEncoder(),
    getApproveTransferInstructionDataDecoder()
  );
}
function getApproveTransferInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    paymentMint: { value: input.paymentMint ?? null, isWritable: false },
    distributionTokenAccount: {
      value: input.distributionTokenAccount ?? null,
      isWritable: true
    },
    authorityTokenAccount: {
      value: input.authorityTokenAccount ?? null,
      isWritable: true
    },
    distributionAccount: {
      value: input.distributionAccount ?? null,
      isWritable: true
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    paymentTokenProgram: {
      value: input.paymentTokenProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.distributionProgram.value) {
    accounts.distributionProgram.value = "diste3nXmK7ddDTs1zb6uday6j4etCa9RChD8fJ1xay";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.paymentMint),
      getAccountMeta(accounts.distributionTokenAccount),
      getAccountMeta(accounts.authorityTokenAccount),
      getAccountMeta(accounts.distributionAccount),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.paymentTokenProgram)
    ],
    programAddress,
    data: getApproveTransferInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseApproveTransferInstruction(instruction) {
  if (instruction.accounts.length < 12) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === WEN_NEW_STANDARD_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      mint: getNextAccount(),
      approveAccount: getNextAccount(),
      paymentMint: getNextAccount(),
      distributionTokenAccount: getNextOptionalAccount(),
      authorityTokenAccount: getNextOptionalAccount(),
      distributionAccount: getNextAccount(),
      systemProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      tokenProgram: getNextAccount(),
      paymentTokenProgram: getNextOptionalAccount()
    },
    data: getApproveTransferInstructionDataDecoder().decode(instruction.data)
  };
}
function getBurnMintAccountInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([60, 58, 247, 183, 185, 54, 114, 131])
    })
  );
}
function getBurnMintAccountInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getBurnMintAccountInstructionDataCodec() {
  return web3_js.combineCodec(
    getBurnMintAccountInstructionDataEncoder(),
    getBurnMintAccountInstructionDataDecoder()
  );
}
function getBurnMintAccountInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    user: { value: input.user ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: true },
    mintTokenAccount: {
      value: input.mintTokenAccount ?? null,
      isWritable: true
    },
    manager: { value: input.manager ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.user),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintTokenAccount),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getBurnMintAccountInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseBurnMintAccountInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      user: getNextAccount(),
      mint: getNextAccount(),
      mintTokenAccount: getNextAccount(),
      manager: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getBurnMintAccountInstructionDataDecoder().decode(instruction.data)
  };
}
function getCreateGroupAccountInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["symbol", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["maxSize", web3_js.getU32Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([34, 65, 118, 12, 64, 190, 211, 145])
    })
  );
}
function getCreateGroupAccountInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["symbol", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["maxSize", web3_js.getU32Decoder()]
  ]);
}
function getCreateGroupAccountInstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateGroupAccountInstructionDataEncoder(),
    getCreateGroupAccountInstructionDataDecoder()
  );
}
function getCreateGroupAccountInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    receiver: { value: input.receiver ?? null, isWritable: false },
    group: { value: input.group ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    mintTokenAccount: {
      value: input.mintTokenAccount ?? null,
      isWritable: true
    },
    manager: { value: input.manager ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.receiver),
      getAccountMeta(accounts.group),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintTokenAccount),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getCreateGroupAccountInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateGroupAccountInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      receiver: getNextAccount(),
      group: getNextAccount(),
      mint: getNextAccount(),
      mintTokenAccount: getNextAccount(),
      manager: getNextAccount(),
      systemProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getCreateGroupAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCreateMintAccountInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["symbol", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["permanentDelegate", web3_js.getOptionEncoder(web3_js.getAddressEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([76, 184, 50, 62, 162, 141, 47, 103])
    })
  );
}
function getCreateMintAccountInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["symbol", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["permanentDelegate", web3_js.getOptionDecoder(web3_js.getAddressDecoder())]
  ]);
}
function getCreateMintAccountInstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateMintAccountInstructionDataEncoder(),
    getCreateMintAccountInstructionDataDecoder()
  );
}
function getCreateMintAccountInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    receiver: { value: input.receiver ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: true },
    mintTokenAccount: {
      value: input.mintTokenAccount ?? null,
      isWritable: true
    },
    manager: { value: input.manager ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.receiver),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintTokenAccount),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getCreateMintAccountInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateMintAccountInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      receiver: getNextAccount(),
      mint: getNextAccount(),
      mintTokenAccount: getNextAccount(),
      manager: getNextAccount(),
      systemProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getCreateMintAccountInstructionDataDecoder().decode(instruction.data)
  };
}
function getExecuteInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["amount", web3_js.getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([105, 37, 101, 197, 75, 251, 102, 26])
    })
  );
}
function getExecuteInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["amount", web3_js.getU64Decoder()]
  ]);
}
function getExecuteInstructionDataCodec() {
  return web3_js.combineCodec(
    getExecuteInstructionDataEncoder(),
    getExecuteInstructionDataDecoder()
  );
}
function getExecuteInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    sourceAccount: { value: input.sourceAccount ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    destinationAccount: {
      value: input.destinationAccount ?? null,
      isWritable: false
    },
    ownerDelegate: { value: input.ownerDelegate ?? null, isWritable: false },
    extraMetasAccount: {
      value: input.extraMetasAccount ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.sourceAccount),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.destinationAccount),
      getAccountMeta(accounts.ownerDelegate),
      getAccountMeta(accounts.extraMetasAccount)
    ],
    programAddress,
    data: getExecuteInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseExecuteInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      sourceAccount: getNextAccount(),
      mint: getNextAccount(),
      destinationAccount: getNextAccount(),
      ownerDelegate: getNextAccount(),
      extraMetasAccount: getNextAccount()
    },
    data: getExecuteInstructionDataDecoder().decode(instruction.data)
  };
}
function getFreezeMintAccountInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([171, 30, 154, 191, 27, 0, 134, 216])
    })
  );
}
function getFreezeMintAccountInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getFreezeMintAccountInstructionDataCodec() {
  return web3_js.combineCodec(
    getFreezeMintAccountInstructionDataEncoder(),
    getFreezeMintAccountInstructionDataDecoder()
  );
}
function getFreezeMintAccountInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    user: { value: input.user ?? null, isWritable: false },
    delegateAuthority: {
      value: input.delegateAuthority ?? null,
      isWritable: true
    },
    mint: { value: input.mint ?? null, isWritable: false },
    mintTokenAccount: {
      value: input.mintTokenAccount ?? null,
      isWritable: true
    },
    manager: { value: input.manager ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.user),
      getAccountMeta(accounts.delegateAuthority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintTokenAccount),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getFreezeMintAccountInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseFreezeMintAccountInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      user: getNextAccount(),
      delegateAuthority: getNextAccount(),
      mint: getNextAccount(),
      mintTokenAccount: getNextAccount(),
      manager: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getFreezeMintAccountInstructionDataDecoder().decode(instruction.data)
  };
}
function getInitManagerAccountInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([63, 114, 69, 118, 3, 198, 215, 72])
    })
  );
}
function getInitManagerAccountInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getInitManagerAccountInstructionDataCodec() {
  return web3_js.combineCodec(
    getInitManagerAccountInstructionDataEncoder(),
    getInitManagerAccountInstructionDataDecoder()
  );
}
function getInitManagerAccountInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    manager: { value: input.manager ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitManagerAccountInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseInitManagerAccountInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      manager: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getInitManagerAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getModifyRoyaltiesInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["args", getUpdateRoyaltiesArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([199, 95, 20, 107, 136, 161, 93, 137])
    })
  );
}
function getModifyRoyaltiesInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["args", getUpdateRoyaltiesArgsDecoder()]
  ]);
}
function getModifyRoyaltiesInstructionDataCodec() {
  return web3_js.combineCodec(
    getModifyRoyaltiesInstructionDataEncoder(),
    getModifyRoyaltiesInstructionDataDecoder()
  );
}
function getModifyRoyaltiesInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getModifyRoyaltiesInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseModifyRoyaltiesInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      mint: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getModifyRoyaltiesInstructionDataDecoder().decode(instruction.data)
  };
}
function getRemoveMetadataInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["args", web3_js.getArrayEncoder(getRemoveMetadataArgsEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([81, 68, 231, 49, 91, 8, 111, 160])
    })
  );
}
function getRemoveMetadataInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["args", web3_js.getArrayDecoder(getRemoveMetadataArgsDecoder())]
  ]);
}
function getRemoveMetadataInstructionDataCodec() {
  return web3_js.combineCodec(
    getRemoveMetadataInstructionDataEncoder(),
    getRemoveMetadataInstructionDataDecoder()
  );
}
function getRemoveMetadataInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getRemoveMetadataInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseRemoveMetadataInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      mint: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getRemoveMetadataInstructionDataDecoder().decode(instruction.data)
  };
}
function getRemoveMintFromGroupInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([231, 224, 145, 240, 192, 4, 204, 218])
    })
  );
}
function getRemoveMintFromGroupInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getRemoveMintFromGroupInstructionDataCodec() {
  return web3_js.combineCodec(
    getRemoveMintFromGroupInstructionDataEncoder(),
    getRemoveMintFromGroupInstructionDataDecoder()
  );
}
function getRemoveMintFromGroupInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    group: { value: input.group ?? null, isWritable: true },
    member: { value: input.member ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    manager: { value: input.manager ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.group),
      getAccountMeta(accounts.member),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getRemoveMintFromGroupInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseRemoveMintFromGroupInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      group: getNextAccount(),
      member: getNextAccount(),
      mint: getNextAccount(),
      manager: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getRemoveMintFromGroupInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getThawMintAccountInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([27, 53, 61, 16, 162, 190, 27, 72])
    })
  );
}
function getThawMintAccountInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)]
  ]);
}
function getThawMintAccountInstructionDataCodec() {
  return web3_js.combineCodec(
    getThawMintAccountInstructionDataEncoder(),
    getThawMintAccountInstructionDataDecoder()
  );
}
function getThawMintAccountInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    user: { value: input.user ?? null, isWritable: false },
    delegateAuthority: {
      value: input.delegateAuthority ?? null,
      isWritable: true
    },
    mint: { value: input.mint ?? null, isWritable: false },
    mintTokenAccount: {
      value: input.mintTokenAccount ?? null,
      isWritable: true
    },
    manager: { value: input.manager ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.user),
      getAccountMeta(accounts.delegateAuthority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintTokenAccount),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getThawMintAccountInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseThawMintAccountInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      user: getNextAccount(),
      delegateAuthority: getNextAccount(),
      mint: getNextAccount(),
      mintTokenAccount: getNextAccount(),
      manager: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getThawMintAccountInstructionDataDecoder().decode(instruction.data)
  };
}
function getUpdateGroupAccountInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 8)],
      ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["symbol", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["maxSize", web3_js.getU32Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([153, 106, 174, 53, 133, 171, 207, 52])
    })
  );
}
function getUpdateGroupAccountInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 8)],
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["symbol", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["maxSize", web3_js.getU32Decoder()]
  ]);
}
function getUpdateGroupAccountInstructionDataCodec() {
  return web3_js.combineCodec(
    getUpdateGroupAccountInstructionDataEncoder(),
    getUpdateGroupAccountInstructionDataDecoder()
  );
}
function getUpdateGroupAccountInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    group: { value: input.group ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.group),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getUpdateGroupAccountInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUpdateGroupAccountInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      group: getNextAccount(),
      mint: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getUpdateGroupAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
async function findApproveAccountPda(seeds, config = {}) {
  const {
    programAddress = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 15).encode(
        new Uint8Array([
          97,
          112,
          112,
          114,
          111,
          118,
          101,
          45,
          97,
          99,
          99,
          111,
          117,
          110,
          116
        ])
      ),
      web3_js.getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findExtraMetasAccountPda(seeds, config = {}) {
  const {
    programAddress = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 19).encode(
        new Uint8Array([
          101,
          120,
          116,
          114,
          97,
          45,
          97,
          99,
          99,
          111,
          117,
          110,
          116,
          45,
          109,
          101,
          116,
          97,
          115
        ])
      ),
      web3_js.getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findGroupPda(seeds, config = {}) {
  const {
    programAddress = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 5).encode(
        new Uint8Array([103, 114, 111, 117, 112])
      ),
      web3_js.getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findManagerPda(config = {}) {
  const {
    programAddress = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 7).encode(
        new Uint8Array([109, 97, 110, 97, 103, 101, 114])
      )
    ]
  });
}
async function findMemberPda(seeds, config = {}) {
  const {
    programAddress = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM"
  } = config;
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 6).encode(
        new Uint8Array([109, 101, 109, 98, 101, 114])
      ),
      web3_js.getAddressEncoder().encode(seeds.mint)
    ]
  });
}

exports.WEN_NEW_STANDARD_ERROR__CREATOR_ADDRESS_INVALID = WEN_NEW_STANDARD_ERROR__CREATOR_ADDRESS_INVALID;
exports.WEN_NEW_STANDARD_ERROR__CREATOR_SHARE_INVALID = WEN_NEW_STANDARD_ERROR__CREATOR_SHARE_INVALID;
exports.WEN_NEW_STANDARD_ERROR__EXPIRED_APPROVE_ACCOUNT = WEN_NEW_STANDARD_ERROR__EXPIRED_APPROVE_ACCOUNT;
exports.WEN_NEW_STANDARD_ERROR__INVALID_FIELD = WEN_NEW_STANDARD_ERROR__INVALID_FIELD;
exports.WEN_NEW_STANDARD_ERROR__MAX_SIZE_BELOW_CURRENT_SIZE = WEN_NEW_STANDARD_ERROR__MAX_SIZE_BELOW_CURRENT_SIZE;
exports.WEN_NEW_STANDARD_ERROR__MISSING_APPROVE_ACCOUNT = WEN_NEW_STANDARD_ERROR__MISSING_APPROVE_ACCOUNT;
exports.WEN_NEW_STANDARD_ERROR__ROYALTY_BASIS_POINTS_INVALID = WEN_NEW_STANDARD_ERROR__ROYALTY_BASIS_POINTS_INVALID;
exports.WEN_NEW_STANDARD_ERROR__SIZE_EXCEEDS_MAX_SIZE = WEN_NEW_STANDARD_ERROR__SIZE_EXCEEDS_MAX_SIZE;
exports.WEN_NEW_STANDARD_PROGRAM_ADDRESS = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
exports.WenNewStandardAccount = WenNewStandardAccount;
exports.WenNewStandardInstruction = WenNewStandardInstruction;
exports.decodeApproveAccount = decodeApproveAccount;
exports.decodeManager = decodeManager;
exports.decodeTokenGroup = decodeTokenGroup;
exports.decodeTokenGroupMember = decodeTokenGroupMember;
exports.fetchAllApproveAccount = fetchAllApproveAccount;
exports.fetchAllManager = fetchAllManager;
exports.fetchAllMaybeApproveAccount = fetchAllMaybeApproveAccount;
exports.fetchAllMaybeManager = fetchAllMaybeManager;
exports.fetchAllMaybeTokenGroup = fetchAllMaybeTokenGroup;
exports.fetchAllMaybeTokenGroupMember = fetchAllMaybeTokenGroupMember;
exports.fetchAllTokenGroup = fetchAllTokenGroup;
exports.fetchAllTokenGroupMember = fetchAllTokenGroupMember;
exports.fetchApproveAccount = fetchApproveAccount;
exports.fetchManager = fetchManager;
exports.fetchMaybeApproveAccount = fetchMaybeApproveAccount;
exports.fetchMaybeManager = fetchMaybeManager;
exports.fetchMaybeTokenGroup = fetchMaybeTokenGroup;
exports.fetchMaybeTokenGroupMember = fetchMaybeTokenGroupMember;
exports.fetchTokenGroup = fetchTokenGroup;
exports.fetchTokenGroupMember = fetchTokenGroupMember;
exports.findApproveAccountPda = findApproveAccountPda;
exports.findExtraMetasAccountPda = findExtraMetasAccountPda;
exports.findGroupPda = findGroupPda;
exports.findManagerPda = findManagerPda;
exports.findMemberPda = findMemberPda;
exports.getAddMetadataArgsCodec = getAddMetadataArgsCodec;
exports.getAddMetadataArgsDecoder = getAddMetadataArgsDecoder;
exports.getAddMetadataArgsEncoder = getAddMetadataArgsEncoder;
exports.getAddMetadataInstruction = getAddMetadataInstruction;
exports.getAddMetadataInstructionDataCodec = getAddMetadataInstructionDataCodec;
exports.getAddMetadataInstructionDataDecoder = getAddMetadataInstructionDataDecoder;
exports.getAddMetadataInstructionDataEncoder = getAddMetadataInstructionDataEncoder;
exports.getAddMintToGroupInstruction = getAddMintToGroupInstruction;
exports.getAddMintToGroupInstructionDataCodec = getAddMintToGroupInstructionDataCodec;
exports.getAddMintToGroupInstructionDataDecoder = getAddMintToGroupInstructionDataDecoder;
exports.getAddMintToGroupInstructionDataEncoder = getAddMintToGroupInstructionDataEncoder;
exports.getAddRoyaltiesInstruction = getAddRoyaltiesInstruction;
exports.getAddRoyaltiesInstructionDataCodec = getAddRoyaltiesInstructionDataCodec;
exports.getAddRoyaltiesInstructionDataDecoder = getAddRoyaltiesInstructionDataDecoder;
exports.getAddRoyaltiesInstructionDataEncoder = getAddRoyaltiesInstructionDataEncoder;
exports.getApproveAccountCodec = getApproveAccountCodec;
exports.getApproveAccountDecoder = getApproveAccountDecoder;
exports.getApproveAccountEncoder = getApproveAccountEncoder;
exports.getApproveAccountSize = getApproveAccountSize;
exports.getApproveTransferInstruction = getApproveTransferInstruction;
exports.getApproveTransferInstructionDataCodec = getApproveTransferInstructionDataCodec;
exports.getApproveTransferInstructionDataDecoder = getApproveTransferInstructionDataDecoder;
exports.getApproveTransferInstructionDataEncoder = getApproveTransferInstructionDataEncoder;
exports.getBurnMintAccountInstruction = getBurnMintAccountInstruction;
exports.getBurnMintAccountInstructionDataCodec = getBurnMintAccountInstructionDataCodec;
exports.getBurnMintAccountInstructionDataDecoder = getBurnMintAccountInstructionDataDecoder;
exports.getBurnMintAccountInstructionDataEncoder = getBurnMintAccountInstructionDataEncoder;
exports.getCreateGroupAccountInstruction = getCreateGroupAccountInstruction;
exports.getCreateGroupAccountInstructionDataCodec = getCreateGroupAccountInstructionDataCodec;
exports.getCreateGroupAccountInstructionDataDecoder = getCreateGroupAccountInstructionDataDecoder;
exports.getCreateGroupAccountInstructionDataEncoder = getCreateGroupAccountInstructionDataEncoder;
exports.getCreateMintAccountInstruction = getCreateMintAccountInstruction;
exports.getCreateMintAccountInstructionDataCodec = getCreateMintAccountInstructionDataCodec;
exports.getCreateMintAccountInstructionDataDecoder = getCreateMintAccountInstructionDataDecoder;
exports.getCreateMintAccountInstructionDataEncoder = getCreateMintAccountInstructionDataEncoder;
exports.getCreatorWithShareCodec = getCreatorWithShareCodec;
exports.getCreatorWithShareDecoder = getCreatorWithShareDecoder;
exports.getCreatorWithShareEncoder = getCreatorWithShareEncoder;
exports.getExecuteInstruction = getExecuteInstruction;
exports.getExecuteInstructionDataCodec = getExecuteInstructionDataCodec;
exports.getExecuteInstructionDataDecoder = getExecuteInstructionDataDecoder;
exports.getExecuteInstructionDataEncoder = getExecuteInstructionDataEncoder;
exports.getFreezeMintAccountInstruction = getFreezeMintAccountInstruction;
exports.getFreezeMintAccountInstructionDataCodec = getFreezeMintAccountInstructionDataCodec;
exports.getFreezeMintAccountInstructionDataDecoder = getFreezeMintAccountInstructionDataDecoder;
exports.getFreezeMintAccountInstructionDataEncoder = getFreezeMintAccountInstructionDataEncoder;
exports.getInitManagerAccountInstruction = getInitManagerAccountInstruction;
exports.getInitManagerAccountInstructionDataCodec = getInitManagerAccountInstructionDataCodec;
exports.getInitManagerAccountInstructionDataDecoder = getInitManagerAccountInstructionDataDecoder;
exports.getInitManagerAccountInstructionDataEncoder = getInitManagerAccountInstructionDataEncoder;
exports.getManagerCodec = getManagerCodec;
exports.getManagerDecoder = getManagerDecoder;
exports.getManagerEncoder = getManagerEncoder;
exports.getManagerSize = getManagerSize;
exports.getModifyRoyaltiesInstruction = getModifyRoyaltiesInstruction;
exports.getModifyRoyaltiesInstructionDataCodec = getModifyRoyaltiesInstructionDataCodec;
exports.getModifyRoyaltiesInstructionDataDecoder = getModifyRoyaltiesInstructionDataDecoder;
exports.getModifyRoyaltiesInstructionDataEncoder = getModifyRoyaltiesInstructionDataEncoder;
exports.getRemoveMetadataArgsCodec = getRemoveMetadataArgsCodec;
exports.getRemoveMetadataArgsDecoder = getRemoveMetadataArgsDecoder;
exports.getRemoveMetadataArgsEncoder = getRemoveMetadataArgsEncoder;
exports.getRemoveMetadataInstruction = getRemoveMetadataInstruction;
exports.getRemoveMetadataInstructionDataCodec = getRemoveMetadataInstructionDataCodec;
exports.getRemoveMetadataInstructionDataDecoder = getRemoveMetadataInstructionDataDecoder;
exports.getRemoveMetadataInstructionDataEncoder = getRemoveMetadataInstructionDataEncoder;
exports.getRemoveMintFromGroupInstruction = getRemoveMintFromGroupInstruction;
exports.getRemoveMintFromGroupInstructionDataCodec = getRemoveMintFromGroupInstructionDataCodec;
exports.getRemoveMintFromGroupInstructionDataDecoder = getRemoveMintFromGroupInstructionDataDecoder;
exports.getRemoveMintFromGroupInstructionDataEncoder = getRemoveMintFromGroupInstructionDataEncoder;
exports.getThawMintAccountInstruction = getThawMintAccountInstruction;
exports.getThawMintAccountInstructionDataCodec = getThawMintAccountInstructionDataCodec;
exports.getThawMintAccountInstructionDataDecoder = getThawMintAccountInstructionDataDecoder;
exports.getThawMintAccountInstructionDataEncoder = getThawMintAccountInstructionDataEncoder;
exports.getTokenGroupCodec = getTokenGroupCodec;
exports.getTokenGroupDecoder = getTokenGroupDecoder;
exports.getTokenGroupEncoder = getTokenGroupEncoder;
exports.getTokenGroupMemberCodec = getTokenGroupMemberCodec;
exports.getTokenGroupMemberDecoder = getTokenGroupMemberDecoder;
exports.getTokenGroupMemberEncoder = getTokenGroupMemberEncoder;
exports.getTokenGroupMemberSize = getTokenGroupMemberSize;
exports.getTokenGroupSize = getTokenGroupSize;
exports.getUpdateGroupAccountInstruction = getUpdateGroupAccountInstruction;
exports.getUpdateGroupAccountInstructionDataCodec = getUpdateGroupAccountInstructionDataCodec;
exports.getUpdateGroupAccountInstructionDataDecoder = getUpdateGroupAccountInstructionDataDecoder;
exports.getUpdateGroupAccountInstructionDataEncoder = getUpdateGroupAccountInstructionDataEncoder;
exports.getUpdateRoyaltiesArgsCodec = getUpdateRoyaltiesArgsCodec;
exports.getUpdateRoyaltiesArgsDecoder = getUpdateRoyaltiesArgsDecoder;
exports.getUpdateRoyaltiesArgsEncoder = getUpdateRoyaltiesArgsEncoder;
exports.getWenNewStandardErrorMessage = getWenNewStandardErrorMessage;
exports.identifyWenNewStandardAccount = identifyWenNewStandardAccount;
exports.identifyWenNewStandardInstruction = identifyWenNewStandardInstruction;
exports.parseAddMetadataInstruction = parseAddMetadataInstruction;
exports.parseAddMintToGroupInstruction = parseAddMintToGroupInstruction;
exports.parseAddRoyaltiesInstruction = parseAddRoyaltiesInstruction;
exports.parseApproveTransferInstruction = parseApproveTransferInstruction;
exports.parseBurnMintAccountInstruction = parseBurnMintAccountInstruction;
exports.parseCreateGroupAccountInstruction = parseCreateGroupAccountInstruction;
exports.parseCreateMintAccountInstruction = parseCreateMintAccountInstruction;
exports.parseExecuteInstruction = parseExecuteInstruction;
exports.parseFreezeMintAccountInstruction = parseFreezeMintAccountInstruction;
exports.parseInitManagerAccountInstruction = parseInitManagerAccountInstruction;
exports.parseModifyRoyaltiesInstruction = parseModifyRoyaltiesInstruction;
exports.parseRemoveMetadataInstruction = parseRemoveMetadataInstruction;
exports.parseRemoveMintFromGroupInstruction = parseRemoveMintFromGroupInstruction;
exports.parseThawMintAccountInstruction = parseThawMintAccountInstruction;
exports.parseUpdateGroupAccountInstruction = parseUpdateGroupAccountInstruction;
//# sourceMappingURL=out.js.map
//# sourceMappingURL=index.js.map