import { transformEncoder, getStructEncoder, fixEncoderSize, getBytesEncoder, getU64Encoder, getStructDecoder, fixDecoderSize, getBytesDecoder, getU64Decoder, combineCodec, decodeAccount, assertAccountExists, fetchEncodedAccount, assertAccountsExist, fetchEncodedAccounts, getAddressEncoder, getU32Encoder, getAddressDecoder, getU32Decoder, containsBytes, addEncoderSizePrefix, getUtf8Encoder, addDecoderSizePrefix, getUtf8Decoder, getU8Encoder, getU8Decoder, getU16Encoder, getArrayEncoder, getU16Decoder, getArrayDecoder, getOptionEncoder, getOptionDecoder, getProgramDerivedAddress, AccountRole, upgradeRoleToSigner, isTransactionSigner as isTransactionSigner$1 } from '@solana/web3.js';

// env-shim.ts
var __DEV__ = /* @__PURE__ */ (() => process["env"].NODE_ENV === "development")();
function getApproveAccountEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["slot", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([218, 253, 170, 2, 4, 47, 25, 99])
    })
  );
}
function getApproveAccountDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["slot", getU64Decoder()]
  ]);
}
function getApproveAccountCodec() {
  return combineCodec(getApproveAccountEncoder(), getApproveAccountDecoder());
}
function decodeApproveAccount(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getApproveAccountDecoder()
  );
}
async function fetchApproveAccount(rpc, address, config) {
  const maybeAccount = await fetchMaybeApproveAccount(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeApproveAccount(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeApproveAccount(maybeAccount);
}
async function fetchAllApproveAccount(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeApproveAccount(
    rpc,
    addresses,
    config
  );
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeApproveAccount(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeApproveAccount(maybeAccount)
  );
}
function getApproveAccountSize() {
  return 16;
}
function getManagerEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([221, 78, 171, 233, 213, 142, 113, 56])
    })
  );
}
function getManagerDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getManagerCodec() {
  return combineCodec(getManagerEncoder(), getManagerDecoder());
}
function decodeManager(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getManagerDecoder()
  );
}
async function fetchManager(rpc, address, config) {
  const maybeAccount = await fetchMaybeManager(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeManager(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeManager(maybeAccount);
}
async function fetchAllManager(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeManager(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeManager(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeManager(maybeAccount));
}
function getManagerSize() {
  return 8;
}
function getTokenGroupEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["updateAuthority", getAddressEncoder()],
      ["mint", getAddressEncoder()],
      ["size", getU32Encoder()],
      ["maxSize", getU32Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([184, 107, 4, 187, 196, 55, 142, 134])
    })
  );
}
function getTokenGroupDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["updateAuthority", getAddressDecoder()],
    ["mint", getAddressDecoder()],
    ["size", getU32Decoder()],
    ["maxSize", getU32Decoder()]
  ]);
}
function getTokenGroupCodec() {
  return combineCodec(getTokenGroupEncoder(), getTokenGroupDecoder());
}
function decodeTokenGroup(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getTokenGroupDecoder()
  );
}
async function fetchTokenGroup(rpc, address, config) {
  const maybeAccount = await fetchMaybeTokenGroup(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeTokenGroup(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeTokenGroup(maybeAccount);
}
async function fetchAllTokenGroup(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeTokenGroup(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeTokenGroup(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeTokenGroup(maybeAccount));
}
function getTokenGroupSize() {
  return 80;
}
function getTokenGroupMemberEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["mint", getAddressEncoder()],
      ["group", getAddressEncoder()],
      ["memberNumber", getU32Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([17, 208, 50, 173, 30, 127, 245, 94])
    })
  );
}
function getTokenGroupMemberDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["mint", getAddressDecoder()],
    ["group", getAddressDecoder()],
    ["memberNumber", getU32Decoder()]
  ]);
}
function getTokenGroupMemberCodec() {
  return combineCodec(
    getTokenGroupMemberEncoder(),
    getTokenGroupMemberDecoder()
  );
}
function decodeTokenGroupMember(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getTokenGroupMemberDecoder()
  );
}
async function fetchTokenGroupMember(rpc, address, config) {
  const maybeAccount = await fetchMaybeTokenGroupMember(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeTokenGroupMember(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeTokenGroupMember(maybeAccount);
}
async function fetchAllTokenGroupMember(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeTokenGroupMember(
    rpc,
    addresses,
    config
  );
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeTokenGroupMember(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodeTokenGroupMember(maybeAccount)
  );
}
function getTokenGroupMemberSize() {
  return 76;
}

// src/generated/errors/wenNewStandard.ts
var WEN_NEW_STANDARD_ERROR__SIZE_EXCEEDS_MAX_SIZE = 6e3;
var WEN_NEW_STANDARD_ERROR__MAX_SIZE_BELOW_CURRENT_SIZE = 6001;
var WEN_NEW_STANDARD_ERROR__CREATOR_SHARE_INVALID = 6002;
var WEN_NEW_STANDARD_ERROR__MISSING_APPROVE_ACCOUNT = 6003;
var WEN_NEW_STANDARD_ERROR__EXPIRED_APPROVE_ACCOUNT = 6004;
var WEN_NEW_STANDARD_ERROR__INVALID_FIELD = 6005;
var WEN_NEW_STANDARD_ERROR__CREATOR_ADDRESS_INVALID = 6006;
var WEN_NEW_STANDARD_ERROR__ROYALTY_BASIS_POINTS_INVALID = 6007;
var wenNewStandardErrorMessages;
if (__DEV__) {
  wenNewStandardErrorMessages = {
    [WEN_NEW_STANDARD_ERROR__CREATOR_ADDRESS_INVALID]: `The Address you provided is invalid. Please provide a valid address.`,
    [WEN_NEW_STANDARD_ERROR__CREATOR_SHARE_INVALID]: `Creators shares must add up to 100.`,
    [WEN_NEW_STANDARD_ERROR__EXPIRED_APPROVE_ACCOUNT]: `Approve account has expired.`,
    [WEN_NEW_STANDARD_ERROR__INVALID_FIELD]: `Invalid field. You cannot use a public key as a field.`,
    [WEN_NEW_STANDARD_ERROR__MAX_SIZE_BELOW_CURRENT_SIZE]: `Max size cannot be reduced below current size.`,
    [WEN_NEW_STANDARD_ERROR__MISSING_APPROVE_ACCOUNT]: `Missing approve account.`,
    [WEN_NEW_STANDARD_ERROR__ROYALTY_BASIS_POINTS_INVALID]: `Royalty basis points must be less than or equal to 10000.`,
    [WEN_NEW_STANDARD_ERROR__SIZE_EXCEEDS_MAX_SIZE]: `Collection size exceeds max size.`
  };
}
function getWenNewStandardErrorMessage(code) {
  if (__DEV__) {
    return wenNewStandardErrorMessages[code];
  }
  return "Error message not available in production bundles. Compile with `__DEV__` set to true to see more information.";
}
var WEN_NEW_STANDARD_PROGRAM_ADDRESS = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM";
var WenNewStandardAccount = /* @__PURE__ */ ((WenNewStandardAccount2) => {
  WenNewStandardAccount2[WenNewStandardAccount2["ApproveAccount"] = 0] = "ApproveAccount";
  WenNewStandardAccount2[WenNewStandardAccount2["Manager"] = 1] = "Manager";
  WenNewStandardAccount2[WenNewStandardAccount2["TokenGroup"] = 2] = "TokenGroup";
  WenNewStandardAccount2[WenNewStandardAccount2["TokenGroupMember"] = 3] = "TokenGroupMember";
  return WenNewStandardAccount2;
})(WenNewStandardAccount || {});
function identifyWenNewStandardAccount(account) {
  const data = account instanceof Uint8Array ? account : account.data;
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([218, 253, 170, 2, 4, 47, 25, 99])
    ),
    0
  )) {
    return 0 /* ApproveAccount */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([221, 78, 171, 233, 213, 142, 113, 56])
    ),
    0
  )) {
    return 1 /* Manager */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([184, 107, 4, 187, 196, 55, 142, 134])
    ),
    0
  )) {
    return 2 /* TokenGroup */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([17, 208, 50, 173, 30, 127, 245, 94])
    ),
    0
  )) {
    return 3 /* TokenGroupMember */;
  }
  throw new Error(
    "The provided account could not be identified as a wenNewStandard account."
  );
}
var WenNewStandardInstruction = /* @__PURE__ */ ((WenNewStandardInstruction2) => {
  WenNewStandardInstruction2[WenNewStandardInstruction2["AddMetadata"] = 0] = "AddMetadata";
  WenNewStandardInstruction2[WenNewStandardInstruction2["AddMintToGroup"] = 1] = "AddMintToGroup";
  WenNewStandardInstruction2[WenNewStandardInstruction2["AddRoyalties"] = 2] = "AddRoyalties";
  WenNewStandardInstruction2[WenNewStandardInstruction2["ApproveTransfer"] = 3] = "ApproveTransfer";
  WenNewStandardInstruction2[WenNewStandardInstruction2["BurnMintAccount"] = 4] = "BurnMintAccount";
  WenNewStandardInstruction2[WenNewStandardInstruction2["CreateGroupAccount"] = 5] = "CreateGroupAccount";
  WenNewStandardInstruction2[WenNewStandardInstruction2["CreateMintAccount"] = 6] = "CreateMintAccount";
  WenNewStandardInstruction2[WenNewStandardInstruction2["Execute"] = 7] = "Execute";
  WenNewStandardInstruction2[WenNewStandardInstruction2["FreezeMintAccount"] = 8] = "FreezeMintAccount";
  WenNewStandardInstruction2[WenNewStandardInstruction2["InitManagerAccount"] = 9] = "InitManagerAccount";
  WenNewStandardInstruction2[WenNewStandardInstruction2["ModifyRoyalties"] = 10] = "ModifyRoyalties";
  WenNewStandardInstruction2[WenNewStandardInstruction2["RemoveMetadata"] = 11] = "RemoveMetadata";
  WenNewStandardInstruction2[WenNewStandardInstruction2["RemoveMintFromGroup"] = 12] = "RemoveMintFromGroup";
  WenNewStandardInstruction2[WenNewStandardInstruction2["ThawMintAccount"] = 13] = "ThawMintAccount";
  WenNewStandardInstruction2[WenNewStandardInstruction2["UpdateGroupAccount"] = 14] = "UpdateGroupAccount";
  return WenNewStandardInstruction2;
})(WenNewStandardInstruction || {});
function identifyWenNewStandardInstruction(instruction) {
  const data = instruction instanceof Uint8Array ? instruction : instruction.data;
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([231, 195, 40, 240, 67, 231, 53, 136])
    ),
    0
  )) {
    return 0 /* AddMetadata */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([236, 25, 99, 48, 185, 60, 235, 112])
    ),
    0
  )) {
    return 1 /* AddMintToGroup */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([195, 251, 126, 230, 187, 134, 168, 210])
    ),
    0
  )) {
    return 2 /* AddRoyalties */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([198, 217, 247, 150, 208, 60, 169, 244])
    ),
    0
  )) {
    return 3 /* ApproveTransfer */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([60, 58, 247, 183, 185, 54, 114, 131])
    ),
    0
  )) {
    return 4 /* BurnMintAccount */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([34, 65, 118, 12, 64, 190, 211, 145])
    ),
    0
  )) {
    return 5 /* CreateGroupAccount */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([76, 184, 50, 62, 162, 141, 47, 103])
    ),
    0
  )) {
    return 6 /* CreateMintAccount */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([105, 37, 101, 197, 75, 251, 102, 26])
    ),
    0
  )) {
    return 7 /* Execute */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([171, 30, 154, 191, 27, 0, 134, 216])
    ),
    0
  )) {
    return 8 /* FreezeMintAccount */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([63, 114, 69, 118, 3, 198, 215, 72])
    ),
    0
  )) {
    return 9 /* InitManagerAccount */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([199, 95, 20, 107, 136, 161, 93, 137])
    ),
    0
  )) {
    return 10 /* ModifyRoyalties */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([81, 68, 231, 49, 91, 8, 111, 160])
    ),
    0
  )) {
    return 11 /* RemoveMetadata */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([231, 224, 145, 240, 192, 4, 204, 218])
    ),
    0
  )) {
    return 12 /* RemoveMintFromGroup */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([27, 53, 61, 16, 162, 190, 27, 72])
    ),
    0
  )) {
    return 13 /* ThawMintAccount */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([153, 106, 174, 53, 133, 171, 207, 52])
    ),
    0
  )) {
    return 14 /* UpdateGroupAccount */;
  }
  throw new Error(
    "The provided instruction could not be identified as a wenNewStandard instruction."
  );
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function getAccountMetaFactory(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      return Object.freeze({
        address: programAddress,
        role: AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? AccountRole.WRITABLE : AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && isTransactionSigner$1(value);
}
function getAddMetadataArgsEncoder() {
  return getStructEncoder([
    ["field", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
    ["value", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())]
  ]);
}
function getAddMetadataArgsDecoder() {
  return getStructDecoder([
    ["field", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["value", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())]
  ]);
}
function getAddMetadataArgsCodec() {
  return combineCodec(getAddMetadataArgsEncoder(), getAddMetadataArgsDecoder());
}
function getCreatorWithShareEncoder() {
  return getStructEncoder([
    ["address", getAddressEncoder()],
    ["share", getU8Encoder()]
  ]);
}
function getCreatorWithShareDecoder() {
  return getStructDecoder([
    ["address", getAddressDecoder()],
    ["share", getU8Decoder()]
  ]);
}
function getCreatorWithShareCodec() {
  return combineCodec(
    getCreatorWithShareEncoder(),
    getCreatorWithShareDecoder()
  );
}
function getRemoveMetadataArgsEncoder() {
  return getStructEncoder([
    ["field", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
    ["value", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())]
  ]);
}
function getRemoveMetadataArgsDecoder() {
  return getStructDecoder([
    ["field", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["value", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())]
  ]);
}
function getRemoveMetadataArgsCodec() {
  return combineCodec(
    getRemoveMetadataArgsEncoder(),
    getRemoveMetadataArgsDecoder()
  );
}
function getUpdateRoyaltiesArgsEncoder() {
  return getStructEncoder([
    ["royaltyBasisPoints", getU16Encoder()],
    ["creators", getArrayEncoder(getCreatorWithShareEncoder())]
  ]);
}
function getUpdateRoyaltiesArgsDecoder() {
  return getStructDecoder([
    ["royaltyBasisPoints", getU16Decoder()],
    ["creators", getArrayDecoder(getCreatorWithShareDecoder())]
  ]);
}
function getUpdateRoyaltiesArgsCodec() {
  return combineCodec(
    getUpdateRoyaltiesArgsEncoder(),
    getUpdateRoyaltiesArgsDecoder()
  );
}

// src/generated/instructions/addMetadata.ts
function getAddMetadataInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["args", getArrayEncoder(getAddMetadataArgsEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([231, 195, 40, 240, 67, 231, 53, 136])
    })
  );
}
function getAddMetadataInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["args", getArrayDecoder(getAddMetadataArgsDecoder())]
  ]);
}
function getAddMetadataInstructionDataCodec() {
  return combineCodec(
    getAddMetadataInstructionDataEncoder(),
    getAddMetadataInstructionDataDecoder()
  );
}
function getAddMetadataInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getAddMetadataInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseAddMetadataInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      mint: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getAddMetadataInstructionDataDecoder().decode(instruction.data)
  };
}
function getAddMintToGroupInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([236, 25, 99, 48, 185, 60, 235, 112])
    })
  );
}
function getAddMintToGroupInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getAddMintToGroupInstructionDataCodec() {
  return combineCodec(
    getAddMintToGroupInstructionDataEncoder(),
    getAddMintToGroupInstructionDataDecoder()
  );
}
function getAddMintToGroupInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    group: { value: input.group ?? null, isWritable: true },
    member: { value: input.member ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    manager: { value: input.manager ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.group),
      getAccountMeta(accounts.member),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getAddMintToGroupInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseAddMintToGroupInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      group: getNextAccount(),
      member: getNextAccount(),
      mint: getNextAccount(),
      manager: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getAddMintToGroupInstructionDataDecoder().decode(instruction.data)
  };
}
function getAddRoyaltiesInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["args", getUpdateRoyaltiesArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([195, 251, 126, 230, 187, 134, 168, 210])
    })
  );
}
function getAddRoyaltiesInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["args", getUpdateRoyaltiesArgsDecoder()]
  ]);
}
function getAddRoyaltiesInstructionDataCodec() {
  return combineCodec(
    getAddRoyaltiesInstructionDataEncoder(),
    getAddRoyaltiesInstructionDataDecoder()
  );
}
function getAddRoyaltiesInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: true },
    extraMetasAccount: {
      value: input.extraMetasAccount ?? null,
      isWritable: true
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.extraMetasAccount),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getAddRoyaltiesInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseAddRoyaltiesInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      mint: getNextAccount(),
      extraMetasAccount: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getAddRoyaltiesInstructionDataDecoder().decode(instruction.data)
  };
}
function getApproveTransferInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["buyAmount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([198, 217, 247, 150, 208, 60, 169, 244])
    })
  );
}
function getApproveTransferInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["buyAmount", getU64Decoder()]
  ]);
}
function getApproveTransferInstructionDataCodec() {
  return combineCodec(
    getApproveTransferInstructionDataEncoder(),
    getApproveTransferInstructionDataDecoder()
  );
}
function getApproveTransferInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    approveAccount: { value: input.approveAccount ?? null, isWritable: true },
    paymentMint: { value: input.paymentMint ?? null, isWritable: false },
    distributionTokenAccount: {
      value: input.distributionTokenAccount ?? null,
      isWritable: true
    },
    authorityTokenAccount: {
      value: input.authorityTokenAccount ?? null,
      isWritable: true
    },
    distributionAccount: {
      value: input.distributionAccount ?? null,
      isWritable: true
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    distributionProgram: {
      value: input.distributionProgram ?? null,
      isWritable: false
    },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false },
    paymentTokenProgram: {
      value: input.paymentTokenProgram ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.distributionProgram.value) {
    accounts.distributionProgram.value = "diste3nXmK7ddDTs1zb6uday6j4etCa9RChD8fJ1xay";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.approveAccount),
      getAccountMeta(accounts.paymentMint),
      getAccountMeta(accounts.distributionTokenAccount),
      getAccountMeta(accounts.authorityTokenAccount),
      getAccountMeta(accounts.distributionAccount),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.distributionProgram),
      getAccountMeta(accounts.tokenProgram),
      getAccountMeta(accounts.paymentTokenProgram)
    ],
    programAddress,
    data: getApproveTransferInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseApproveTransferInstruction(instruction) {
  if (instruction.accounts.length < 12) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === WEN_NEW_STANDARD_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      mint: getNextAccount(),
      approveAccount: getNextAccount(),
      paymentMint: getNextAccount(),
      distributionTokenAccount: getNextOptionalAccount(),
      authorityTokenAccount: getNextOptionalAccount(),
      distributionAccount: getNextAccount(),
      systemProgram: getNextAccount(),
      distributionProgram: getNextAccount(),
      tokenProgram: getNextAccount(),
      paymentTokenProgram: getNextOptionalAccount()
    },
    data: getApproveTransferInstructionDataDecoder().decode(instruction.data)
  };
}
function getBurnMintAccountInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([60, 58, 247, 183, 185, 54, 114, 131])
    })
  );
}
function getBurnMintAccountInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getBurnMintAccountInstructionDataCodec() {
  return combineCodec(
    getBurnMintAccountInstructionDataEncoder(),
    getBurnMintAccountInstructionDataDecoder()
  );
}
function getBurnMintAccountInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    user: { value: input.user ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: true },
    mintTokenAccount: {
      value: input.mintTokenAccount ?? null,
      isWritable: true
    },
    manager: { value: input.manager ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.user),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintTokenAccount),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getBurnMintAccountInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseBurnMintAccountInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      user: getNextAccount(),
      mint: getNextAccount(),
      mintTokenAccount: getNextAccount(),
      manager: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getBurnMintAccountInstructionDataDecoder().decode(instruction.data)
  };
}
function getCreateGroupAccountInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["name", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
      ["symbol", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
      ["uri", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
      ["maxSize", getU32Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([34, 65, 118, 12, 64, 190, 211, 145])
    })
  );
}
function getCreateGroupAccountInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["name", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["symbol", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["uri", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["maxSize", getU32Decoder()]
  ]);
}
function getCreateGroupAccountInstructionDataCodec() {
  return combineCodec(
    getCreateGroupAccountInstructionDataEncoder(),
    getCreateGroupAccountInstructionDataDecoder()
  );
}
function getCreateGroupAccountInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    receiver: { value: input.receiver ?? null, isWritable: false },
    group: { value: input.group ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    mintTokenAccount: {
      value: input.mintTokenAccount ?? null,
      isWritable: true
    },
    manager: { value: input.manager ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.receiver),
      getAccountMeta(accounts.group),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintTokenAccount),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getCreateGroupAccountInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateGroupAccountInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      receiver: getNextAccount(),
      group: getNextAccount(),
      mint: getNextAccount(),
      mintTokenAccount: getNextAccount(),
      manager: getNextAccount(),
      systemProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getCreateGroupAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCreateMintAccountInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["name", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
      ["symbol", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
      ["uri", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
      ["permanentDelegate", getOptionEncoder(getAddressEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([76, 184, 50, 62, 162, 141, 47, 103])
    })
  );
}
function getCreateMintAccountInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["name", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["symbol", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["uri", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["permanentDelegate", getOptionDecoder(getAddressDecoder())]
  ]);
}
function getCreateMintAccountInstructionDataCodec() {
  return combineCodec(
    getCreateMintAccountInstructionDataEncoder(),
    getCreateMintAccountInstructionDataDecoder()
  );
}
function getCreateMintAccountInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    receiver: { value: input.receiver ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: true },
    mintTokenAccount: {
      value: input.mintTokenAccount ?? null,
      isWritable: true
    },
    manager: { value: input.manager ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    associatedTokenProgram: {
      value: input.associatedTokenProgram ?? null,
      isWritable: false
    },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.associatedTokenProgram.value) {
    accounts.associatedTokenProgram.value = "ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.receiver),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintTokenAccount),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.associatedTokenProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getCreateMintAccountInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateMintAccountInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      receiver: getNextAccount(),
      mint: getNextAccount(),
      mintTokenAccount: getNextAccount(),
      manager: getNextAccount(),
      systemProgram: getNextAccount(),
      associatedTokenProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getCreateMintAccountInstructionDataDecoder().decode(instruction.data)
  };
}
function getExecuteInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["amount", getU64Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([105, 37, 101, 197, 75, 251, 102, 26])
    })
  );
}
function getExecuteInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["amount", getU64Decoder()]
  ]);
}
function getExecuteInstructionDataCodec() {
  return combineCodec(
    getExecuteInstructionDataEncoder(),
    getExecuteInstructionDataDecoder()
  );
}
function getExecuteInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    sourceAccount: { value: input.sourceAccount ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    destinationAccount: {
      value: input.destinationAccount ?? null,
      isWritable: false
    },
    ownerDelegate: { value: input.ownerDelegate ?? null, isWritable: false },
    extraMetasAccount: {
      value: input.extraMetasAccount ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.sourceAccount),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.destinationAccount),
      getAccountMeta(accounts.ownerDelegate),
      getAccountMeta(accounts.extraMetasAccount)
    ],
    programAddress,
    data: getExecuteInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseExecuteInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      sourceAccount: getNextAccount(),
      mint: getNextAccount(),
      destinationAccount: getNextAccount(),
      ownerDelegate: getNextAccount(),
      extraMetasAccount: getNextAccount()
    },
    data: getExecuteInstructionDataDecoder().decode(instruction.data)
  };
}
function getFreezeMintAccountInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([171, 30, 154, 191, 27, 0, 134, 216])
    })
  );
}
function getFreezeMintAccountInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getFreezeMintAccountInstructionDataCodec() {
  return combineCodec(
    getFreezeMintAccountInstructionDataEncoder(),
    getFreezeMintAccountInstructionDataDecoder()
  );
}
function getFreezeMintAccountInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    user: { value: input.user ?? null, isWritable: false },
    delegateAuthority: {
      value: input.delegateAuthority ?? null,
      isWritable: true
    },
    mint: { value: input.mint ?? null, isWritable: false },
    mintTokenAccount: {
      value: input.mintTokenAccount ?? null,
      isWritable: true
    },
    manager: { value: input.manager ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.user),
      getAccountMeta(accounts.delegateAuthority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintTokenAccount),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getFreezeMintAccountInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseFreezeMintAccountInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      user: getNextAccount(),
      delegateAuthority: getNextAccount(),
      mint: getNextAccount(),
      mintTokenAccount: getNextAccount(),
      manager: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getFreezeMintAccountInstructionDataDecoder().decode(instruction.data)
  };
}
function getInitManagerAccountInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([63, 114, 69, 118, 3, 198, 215, 72])
    })
  );
}
function getInitManagerAccountInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getInitManagerAccountInstructionDataCodec() {
  return combineCodec(
    getInitManagerAccountInstructionDataEncoder(),
    getInitManagerAccountInstructionDataDecoder()
  );
}
function getInitManagerAccountInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    manager: { value: input.manager ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitManagerAccountInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseInitManagerAccountInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      manager: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getInitManagerAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getModifyRoyaltiesInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["args", getUpdateRoyaltiesArgsEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([199, 95, 20, 107, 136, 161, 93, 137])
    })
  );
}
function getModifyRoyaltiesInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["args", getUpdateRoyaltiesArgsDecoder()]
  ]);
}
function getModifyRoyaltiesInstructionDataCodec() {
  return combineCodec(
    getModifyRoyaltiesInstructionDataEncoder(),
    getModifyRoyaltiesInstructionDataDecoder()
  );
}
function getModifyRoyaltiesInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getModifyRoyaltiesInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseModifyRoyaltiesInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      mint: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getModifyRoyaltiesInstructionDataDecoder().decode(instruction.data)
  };
}
function getRemoveMetadataInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["args", getArrayEncoder(getRemoveMetadataArgsEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([81, 68, 231, 49, 91, 8, 111, 160])
    })
  );
}
function getRemoveMetadataInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["args", getArrayDecoder(getRemoveMetadataArgsDecoder())]
  ]);
}
function getRemoveMetadataInstructionDataCodec() {
  return combineCodec(
    getRemoveMetadataInstructionDataEncoder(),
    getRemoveMetadataInstructionDataDecoder()
  );
}
function getRemoveMetadataInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getRemoveMetadataInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseRemoveMetadataInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      mint: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getRemoveMetadataInstructionDataDecoder().decode(instruction.data)
  };
}
function getRemoveMintFromGroupInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([231, 224, 145, 240, 192, 4, 204, 218])
    })
  );
}
function getRemoveMintFromGroupInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getRemoveMintFromGroupInstructionDataCodec() {
  return combineCodec(
    getRemoveMintFromGroupInstructionDataEncoder(),
    getRemoveMintFromGroupInstructionDataDecoder()
  );
}
function getRemoveMintFromGroupInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    group: { value: input.group ?? null, isWritable: true },
    member: { value: input.member ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    manager: { value: input.manager ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.group),
      getAccountMeta(accounts.member),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getRemoveMintFromGroupInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseRemoveMintFromGroupInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      group: getNextAccount(),
      member: getNextAccount(),
      mint: getNextAccount(),
      manager: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getRemoveMintFromGroupInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getThawMintAccountInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([27, 53, 61, 16, 162, 190, 27, 72])
    })
  );
}
function getThawMintAccountInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getThawMintAccountInstructionDataCodec() {
  return combineCodec(
    getThawMintAccountInstructionDataEncoder(),
    getThawMintAccountInstructionDataDecoder()
  );
}
function getThawMintAccountInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    user: { value: input.user ?? null, isWritable: false },
    delegateAuthority: {
      value: input.delegateAuthority ?? null,
      isWritable: true
    },
    mint: { value: input.mint ?? null, isWritable: false },
    mintTokenAccount: {
      value: input.mintTokenAccount ?? null,
      isWritable: true
    },
    manager: { value: input.manager ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.user),
      getAccountMeta(accounts.delegateAuthority),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintTokenAccount),
      getAccountMeta(accounts.manager),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getThawMintAccountInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseThawMintAccountInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      user: getNextAccount(),
      delegateAuthority: getNextAccount(),
      mint: getNextAccount(),
      mintTokenAccount: getNextAccount(),
      manager: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getThawMintAccountInstructionDataDecoder().decode(instruction.data)
  };
}
function getUpdateGroupAccountInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["name", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
      ["symbol", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
      ["uri", addEncoderSizePrefix(getUtf8Encoder(), getU32Encoder())],
      ["maxSize", getU32Encoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([153, 106, 174, 53, 133, 171, 207, 52])
    })
  );
}
function getUpdateGroupAccountInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["name", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["symbol", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["uri", addDecoderSizePrefix(getUtf8Decoder(), getU32Decoder())],
    ["maxSize", getU32Decoder()]
  ]);
}
function getUpdateGroupAccountInstructionDataCodec() {
  return combineCodec(
    getUpdateGroupAccountInstructionDataEncoder(),
    getUpdateGroupAccountInstructionDataDecoder()
  );
}
function getUpdateGroupAccountInstruction(input) {
  const programAddress = WEN_NEW_STANDARD_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    group: { value: input.group ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenzQdBNbLqP5VEhdkAS6EPFLC1PHnBqCXEpPxuEb";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.group),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getUpdateGroupAccountInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUpdateGroupAccountInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      authority: getNextAccount(),
      group: getNextAccount(),
      mint: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getUpdateGroupAccountInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
async function findApproveAccountPda(seeds, config = {}) {
  const {
    programAddress = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      fixEncoderSize(getBytesEncoder(), 15).encode(
        new Uint8Array([
          97,
          112,
          112,
          114,
          111,
          118,
          101,
          45,
          97,
          99,
          99,
          111,
          117,
          110,
          116
        ])
      ),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findExtraMetasAccountPda(seeds, config = {}) {
  const {
    programAddress = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      fixEncoderSize(getBytesEncoder(), 19).encode(
        new Uint8Array([
          101,
          120,
          116,
          114,
          97,
          45,
          97,
          99,
          99,
          111,
          117,
          110,
          116,
          45,
          109,
          101,
          116,
          97,
          115
        ])
      ),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findGroupPda(seeds, config = {}) {
  const {
    programAddress = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      fixEncoderSize(getBytesEncoder(), 5).encode(
        new Uint8Array([103, 114, 111, 117, 112])
      ),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findManagerPda(config = {}) {
  const {
    programAddress = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      fixEncoderSize(getBytesEncoder(), 7).encode(
        new Uint8Array([109, 97, 110, 97, 103, 101, 114])
      )
    ]
  });
}
async function findMemberPda(seeds, config = {}) {
  const {
    programAddress = "wns1gDLt8fgLcGhWi5MqAqgXpwEP1JftKE9eZnXS1HM"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      fixEncoderSize(getBytesEncoder(), 6).encode(
        new Uint8Array([109, 101, 109, 98, 101, 114])
      ),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}

export { WEN_NEW_STANDARD_ERROR__CREATOR_ADDRESS_INVALID, WEN_NEW_STANDARD_ERROR__CREATOR_SHARE_INVALID, WEN_NEW_STANDARD_ERROR__EXPIRED_APPROVE_ACCOUNT, WEN_NEW_STANDARD_ERROR__INVALID_FIELD, WEN_NEW_STANDARD_ERROR__MAX_SIZE_BELOW_CURRENT_SIZE, WEN_NEW_STANDARD_ERROR__MISSING_APPROVE_ACCOUNT, WEN_NEW_STANDARD_ERROR__ROYALTY_BASIS_POINTS_INVALID, WEN_NEW_STANDARD_ERROR__SIZE_EXCEEDS_MAX_SIZE, WEN_NEW_STANDARD_PROGRAM_ADDRESS, WenNewStandardAccount, WenNewStandardInstruction, decodeApproveAccount, decodeManager, decodeTokenGroup, decodeTokenGroupMember, fetchAllApproveAccount, fetchAllManager, fetchAllMaybeApproveAccount, fetchAllMaybeManager, fetchAllMaybeTokenGroup, fetchAllMaybeTokenGroupMember, fetchAllTokenGroup, fetchAllTokenGroupMember, fetchApproveAccount, fetchManager, fetchMaybeApproveAccount, fetchMaybeManager, fetchMaybeTokenGroup, fetchMaybeTokenGroupMember, fetchTokenGroup, fetchTokenGroupMember, findApproveAccountPda, findExtraMetasAccountPda, findGroupPda, findManagerPda, findMemberPda, getAddMetadataArgsCodec, getAddMetadataArgsDecoder, getAddMetadataArgsEncoder, getAddMetadataInstruction, getAddMetadataInstructionDataCodec, getAddMetadataInstructionDataDecoder, getAddMetadataInstructionDataEncoder, getAddMintToGroupInstruction, getAddMintToGroupInstructionDataCodec, getAddMintToGroupInstructionDataDecoder, getAddMintToGroupInstructionDataEncoder, getAddRoyaltiesInstruction, getAddRoyaltiesInstructionDataCodec, getAddRoyaltiesInstructionDataDecoder, getAddRoyaltiesInstructionDataEncoder, getApproveAccountCodec, getApproveAccountDecoder, getApproveAccountEncoder, getApproveAccountSize, getApproveTransferInstruction, getApproveTransferInstructionDataCodec, getApproveTransferInstructionDataDecoder, getApproveTransferInstructionDataEncoder, getBurnMintAccountInstruction, getBurnMintAccountInstructionDataCodec, getBurnMintAccountInstructionDataDecoder, getBurnMintAccountInstructionDataEncoder, getCreateGroupAccountInstruction, getCreateGroupAccountInstructionDataCodec, getCreateGroupAccountInstructionDataDecoder, getCreateGroupAccountInstructionDataEncoder, getCreateMintAccountInstruction, getCreateMintAccountInstructionDataCodec, getCreateMintAccountInstructionDataDecoder, getCreateMintAccountInstructionDataEncoder, getCreatorWithShareCodec, getCreatorWithShareDecoder, getCreatorWithShareEncoder, getExecuteInstruction, getExecuteInstructionDataCodec, getExecuteInstructionDataDecoder, getExecuteInstructionDataEncoder, getFreezeMintAccountInstruction, getFreezeMintAccountInstructionDataCodec, getFreezeMintAccountInstructionDataDecoder, getFreezeMintAccountInstructionDataEncoder, getInitManagerAccountInstruction, getInitManagerAccountInstructionDataCodec, getInitManagerAccountInstructionDataDecoder, getInitManagerAccountInstructionDataEncoder, getManagerCodec, getManagerDecoder, getManagerEncoder, getManagerSize, getModifyRoyaltiesInstruction, getModifyRoyaltiesInstructionDataCodec, getModifyRoyaltiesInstructionDataDecoder, getModifyRoyaltiesInstructionDataEncoder, getRemoveMetadataArgsCodec, getRemoveMetadataArgsDecoder, getRemoveMetadataArgsEncoder, getRemoveMetadataInstruction, getRemoveMetadataInstructionDataCodec, getRemoveMetadataInstructionDataDecoder, getRemoveMetadataInstructionDataEncoder, getRemoveMintFromGroupInstruction, getRemoveMintFromGroupInstructionDataCodec, getRemoveMintFromGroupInstructionDataDecoder, getRemoveMintFromGroupInstructionDataEncoder, getThawMintAccountInstruction, getThawMintAccountInstructionDataCodec, getThawMintAccountInstructionDataDecoder, getThawMintAccountInstructionDataEncoder, getTokenGroupCodec, getTokenGroupDecoder, getTokenGroupEncoder, getTokenGroupMemberCodec, getTokenGroupMemberDecoder, getTokenGroupMemberEncoder, getTokenGroupMemberSize, getTokenGroupSize, getUpdateGroupAccountInstruction, getUpdateGroupAccountInstructionDataCodec, getUpdateGroupAccountInstructionDataDecoder, getUpdateGroupAccountInstructionDataEncoder, getUpdateRoyaltiesArgsCodec, getUpdateRoyaltiesArgsDecoder, getUpdateRoyaltiesArgsEncoder, getWenNewStandardErrorMessage, identifyWenNewStandardAccount, identifyWenNewStandardInstruction, parseAddMetadataInstruction, parseAddMintToGroupInstruction, parseAddRoyaltiesInstruction, parseApproveTransferInstruction, parseBurnMintAccountInstruction, parseCreateGroupAccountInstruction, parseCreateMintAccountInstruction, parseExecuteInstruction, parseFreezeMintAccountInstruction, parseInitManagerAccountInstruction, parseModifyRoyaltiesInstruction, parseRemoveMetadataInstruction, parseRemoveMintFromGroupInstruction, parseThawMintAccountInstruction, parseUpdateGroupAccountInstruction };
//# sourceMappingURL=out.js.map
//# sourceMappingURL=index.mjs.map